@@ -3,15 +3,15 @@ from .context.context import Context
 
 # Import events
 from .events.api_gateway_proxy import APIGatewayProxyEventV1, APIGatewayProxyEventV2
-from .events.cloudwatch_events import CloudWatchEventsMessageEvent
-from .events.cloudwatch_logs import CloudWatchLogsEvent
-from .events.codepipeline import CodePipelineEvent
+from .events.cloud_watch_events import CloudWatchEventsMessageEvent
+from .events.cloud_watch_logs import CloudWatchLogsEvent
+from .events.code_pipeline import CodePipelineEvent
 from .events.config import ConfigEvent
 from .events.dynamodb_stream import DynamoDBStreamEvent
 from .events.kinesis_firehose import KinesisFirehoseEvent
 from .events.kinesis_stream import KinesisStreamEvent
 from .events.mq import MQEvent
-from .events.s3_batch import S3BatchRequestEvent
+from .events.s3_batch import S3BatchEvent
 from .events.s3 import S3Event
 from .events.ses import SESEvent
 from .events.sns import SNSEvent
